{ config, lib, pkgs, modulesPath, ... }:
{
  imports = [
    (modulesPath + "/installer/scan/not-detected.nix")
  ];

  boot = {
    blacklistedKernelModules = [
      "pcspkr"
    ];
    initrd = {
      availableKernelModules = [
        "xhci_pci"
        "ehci_pci"
        "ahci"
        "nvme"
        "usbhid"
        "sd_mod"
        "sr_mod"
      ];
      kernelModules = [
        "kvm-intel"
      ];
    };
    swraid = {
      enable = true;
      mdadmConf = "MAILADDR jimbo@jimbosfiles.com";
    };
  };

  fileSystems = {
    "/" = {
      device = "/dev/disk/by-uuid/b8b7ed47-c98c-4a49-af01-b2832dde1287";
      fsType = "btrfs";
      options = [ "subvol=@" ];
    };
    "/home" = {
      device = "/dev/disk/by-uuid/b8b7ed47-c98c-4a49-af01-b2832dde1287";
      fsType = "btrfs";
      options = [ "subvol=@home" ];
    };
    "/nix" = {
      device = "/dev/disk/by-uuid/b8b7ed47-c98c-4a49-af01-b2832dde1287";
      fsType = "btrfs";
      options = [ "subvol=@nix" ];
    };
    "/var" = {
      device = "/dev/disk/by-uuid/b8b7ed47-c98c-4a49-af01-b2832dde1287";
      fsType = "btrfs";
      options = [ "subvol=@var" ];
    };
    "/.snapshots" = {
      device = "/dev/disk/by-uuid/b8b7ed47-c98c-4a49-af01-b2832dde1287";
      fsType = "btrfs";
      options = [ "subvol=@snapshots" ];
    };
    "/boot" = {
      device = "/dev/disk/by-uuid/CD94-1D3F";
      fsType = "vfat";
      options = [ "fmask=0022" "dmask=0022" ];
    };
    "/export/JimboNFS" = {
      device = "/dev/disk/by-uuid/713fcd92-534c-4153-8e04-e0c6fe5f6a51";
      fsType = "ext4";
      noCheck = true;
    };

    # Atrocity of bindmounts
    "/home/jimbo/JimboNFS" = {
      device = "/export/JimboNFS";
      fsType = "none";
      options = [ "bind" ];
    };
    "/mnt/nextcloud/data/JimboNFS" = {
      device = "/export/JimboNFS";
      fsType = "none";
      options = [ "bind" ];
    };
    "/var/lib/bitwarden_rs" = {
      device = "/export/JimboNFS/System/var/lib/bitwarden_rs";
      fsType = "none";
      options = [ "bind" ];
    };
    "/var/lib/forgejo" = {
      device = "/export/JimboNFS/System/var/lib/forgejo";
      fsType = "none";
      options = [ "bind" ];
    };
    "/var/lib/matrix-synapse" = {
      device = "/export/JimboNFS/System/var/lib/matrix-synapse";
      fsType = "none";
      options = [ "bind" ];
    };
    "/var/lib/nextcloud" = {
      device = "/export/JimboNFS/System/var/lib/nextcloud";
      fsType = "none";
      options = [ "bind" ];
    };
    "/var/lib/owncast" = {
      device = "/export/JimboNFS/System/var/lib/owncast";
      fsType = "none";
      options = [ "bind" ];
    };
    "/var/lib/mastodon" = {
      device = "/export/JimboNFS/System/var/lib/mastodon";
      fsType = "none";
      options = [ "bind" ];
    };
    "/srv/minecraft" = {
      device = "/export/JimboNFS/System/srv/minecraft";
      fsType = "none";
      options = [ "bind" ];
    };
    "/var/lib/private/photoprism/originals" = {
      device = "/export/JimboNFS/Photos/Galleries";
      fsType = "none";
      options = [ "bind" ];
    };
  };

  swapDevices = [
    { device = "/dev/disk/by-uuid/57178cfc-3e71-4d35-8c7f-e355f9dc84df"; }
  ];

  networking.useDHCP = lib.mkDefault true;
  nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";
  hardware.cpu.amd.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
}
